<?php
/**
 * Plugin Name: eBook Watermark by DynamicInk
 * Plugin URI: https://www.dynamicink.co
 * Description: Watermark your eBook with customer's name, email, etc. Support PDF, epub, mobi
 * Author: DynamicInk
 * Author URI: https://www.dynamicink.co
 * Version: 1.0.2
 * WC requires at least: 5.0
 * Text Domain: DynamicInk
 * Domain Path: languages/
 */




if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Dynamicink_Integration' ) ) {

	define( 'DYNAMICINK_INTEGRATION_VERSION', '1.0.0' ); // WRCS: DEFINED_VERSION.
    define( 'DYNAMICINK_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

	/**
	 * Ebook Watermark DynamicInk Integration main class.
	 */
	class Dynamicink_Integration {

		/** @var Dynamicink_Integration $instance Instance of this class. */
		protected static $instance = null;

		/**
		 * Initialize the plugin.
		 */
		public function __construct() {
			if ( ! class_exists( 'WooCommerce' ) ) {
				return;
			}

			// Load plugin text domain
			add_action( 'init', array( $this, 'load_plugin_textdomain' ) );

			// Checks which WooCommerce is installed.
			if ( class_exists( 'WC_Integration' ) && defined( 'WOOCOMMERCE_VERSION' ) && version_compare( WOOCOMMERCE_VERSION, '3.2', '>=' ) ) {
				include_once 'includes/dynamicink-api.php';

				// Register the integration.
				add_filter( 'woocommerce_integrations', array( $this, 'dynamicink_add_integration' ) );
			}
            // Setting action for plugin
            add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_links' ) );
		}
        
        /**
		 * Add links on the plugins page (Settings & Support)
		 *
		 * @param  array $links Default links
		 * @return array        Default + added links
		 */
		public function plugin_links( $links ) {
            $settings_url = add_query_arg(
				array(
					'page'    => 'wc-settings',
					'tab'     => 'integration',
					'section' => 'dynamicink',
				),
				admin_url( 'admin.php' )
			);

			$plugin_links = array(
				'<a href="' . esc_url( $settings_url ) . '">' . __( 'Settings', 'dynamicink' ) . '</a>'
			);

			return array_merge( $plugin_links, $links );            
        }

		/**
		 * Return an instance of this class.
		 *
		 * @return Dynamicink_Integration A single instance of this class.
		 */
		public static function get_instance() {
			// If the single instance hasn't been set, set it now.
			if ( null == self::$instance ) {
				self::$instance = new self;
			}

			return self::$instance;
		}

		/**
		 * Load the plugin text domain for translation.
		 */
		public function load_plugin_textdomain() {
			$locale = apply_filters( 'plugin_locale', get_locale(), 'dynamicink' );

			load_textdomain( 'dynamicink', trailingslashit( WP_LANG_DIR ) . 'dynamicink/dynamicink-' . $locale . '.mo' );
			load_plugin_textdomain( 'dynamicink', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
		}

		/**
		 * Add a new integration to WooCommerce.
		 *
		 * @param  array $integrations WooCommerce integrations.
		 * @return array            
		 */
		public function dynamicink_add_integration( $integrations ) {
			$integrations[] = 'Dynamicink_Ebook_Api';

			return $integrations;
		}
	}

	add_action( 'plugins_loaded', array( 'Dynamicink_Integration', 'get_instance' ), 0 );

}
