<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Dynamicink Ebook API
 *
 * @class   Dynamicink_Ebook_Api
 * @extends WC_Integration
 *
 * @property $ebook_api_key
 */
class Dynamicink_Ebook_Api extends WC_Integration {

	/**
	 * Constructor
	 * Init and hook in the integration.
	 */
	public function __construct() {
		$this->id                    = 'dynamicink';
		$this->method_title          = __( 'DynamicInk API', 'dynamicink' );
		$this->method_description    = __( 'Watermark ebook using DynamicInk service', 'dynamicink' );
		$this->dismissed_info_banner = get_option( 'woocommerce_dismissed_info_banner' );
        
        $this->ebook_api_url          = 'https://dynamicink.co/purchase/';
        
        
        // Load the settings
		$this->init_settings();		
        $constructor = $this->dynamicink_init_options();
        $this->dynamicink_init_form_fields();

        // Actions.
		add_action( 'woocommerce_update_options_integration_' .  $this->id, array( $this, 'process_admin_options' ) );

		// Filters.
		add_filter( 'woocommerce_settings_api_sanitized_fields_' . $this->id, array( $this, 'dynamicink_sanitize_settings' ) );

        // The code for displaying WooCommerce Product Custom Fields
        add_action( 'woocommerce_product_options_general_product_data', array( $this, 'dynamicink_product_custom_fields' ) ); 
        // Following code Saves  WooCommerce Product Custom Fields
        add_action( 'woocommerce_process_product_meta', array( $this, 'dynamicink_product_custom_fields_save' ) );

		
		add_action( 'woocommerce_thankyou', array( $this, 'dynamicink_ebook_api_send_details' ) );
        add_action( 'woocommerce_pre_payment_complete', array( $this, 'dynamicink_ebook_api_send_details' ) ); 
        add_action( 'woocommerce_email_after_order_table', array( $this, 'dynamicink_order_ebook_downloads' ), 30, 10);
	}
    
    /**
	 * Show order downloads in a table.
	 *
	 * @since 3.2.0
	 * @param WC_Order $order         Order instance.
	 * @param bool     $sent_to_admin If should sent to admin.
	 * @param bool     $plain_text    If is plain text email.
	 * @param string   $email         Email address.
	 */
	public function dynamicink_order_ebook_downloads( $order, $sent_to_admin = false, $plain_text = false, $email = '' ) {
        $order_id = $order->get_id();
        $downloadable_watermark_files_final = json_decode(get_post_meta($order_id, 'downloadable_watermark_files', true));
		if( count((array)$downloadable_watermark_files_final) > 0 && $this->ebook_api_key !=''){
            $columns   = apply_filters(
                'woocommerce_email_downloads_columns',
                array(
                    'download-product' => __( 'Product', 'woocommerce' ),
                    'download-remaining' => __( 'Downloads remaining', 'woocommerce' ),
                    'download-expires' => __( 'Expires', 'woocommerce' ),
                    'download-file'    => __( 'Download', 'woocommerce' ),
                )
            );

            if ( $plain_text ) {
                wc_get_template(
                    '../../ebook-watermark-by-dynamicink/includes/plain/dynamicink-email-downloads.php',
                    array(
                        'order'         => $order,
                        'ebook_api_url' => $this->ebook_api_url,
                        'sent_to_admin' => $sent_to_admin,
                        'plain_text'    => $plain_text,
                        'email'         => $email,
                        'downloads'     => $downloadable_watermark_files_final,
                        'columns'       => $columns,
                    )
                );
            } else {
                wc_get_template(
                    '../../ebook-watermark-by-dynamicink/includes/dynamicink-email-downloads.php',
                    array(
                        'order'         => $order,
                        'sent_to_admin' => $sent_to_admin,
                        'ebook_api_url' => $this->ebook_api_url,
                        'plain_text'    => $plain_text,
                        'email'         => $email,
                        'downloads'     => $downloadable_watermark_files_final,
                        'columns'       => $columns,
                    )
                );
            }
        }
	}
    
    function wpse_336136_load_template( $template_name ) {
        $template_name = ltrim( $template_name, '/' );
        $template_path = locate_template( 'ebook-watermark-by-dynamicink/' . $template_name );

        if ( ! $template_path ) {
            $template_path = plugin_dir_path( 'templates/' . $template_name, __FILE__ );
        }

        return $template_path;
    }
    
    function dynamicink_get_gdpr_customer_email($email) {
        $emailArray = explode('@',$email);
        $len = strlen($emailArray[0]);
        return substr($emailArray[0], 0, 1).str_repeat('*', $len-2).substr($emailArray[0], $len - 1, 1).'@'.$emailArray[1];
    }
    
    function dynamicink_generateRandomString($length = 15) {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }
    
    function dynamicink_ebook_api_send_details( $order_id ){
        // get order object and order details
        $order = new WC_Order( $order_id );
        $downloadable_watermark_files_final = json_decode(get_post_meta($order_id, 'downloadable_watermark_files', true));
        if(count((array)$downloadable_watermark_files_final) ==0 && $this->ebook_api_key !=''){
            $email = $order->billing_email;

            $user_id = $order->user_id;
            $address_fields = array(
                'first_name',
                'last_name');

            $address = array();
            if(is_array($address_fields)){
                foreach($address_fields as $field){
                    $address['billing_'.$field] = get_user_meta( $user_id, 'billing_'.$field, true );
                }
            }
            
            $address['first_name'] = empty($address['first_name']) ? $order->get_billing_first_name() : $address['first_name'];
            $address['last_name'] = empty($address['last_name']) ? $order->get_billing_last_name() : $address['last_name'];
            
            // get product details
            $items = $order->get_items();           
            
            $item_id      = array();
            $item_download_count = '';
            $item_download_expiry = '';
            $from_date = $order->get_date_completed() ? $order->get_date_completed()->format( 'Y-m-d' ) : current_time( 'mysql', true );
            $return_response = [];
            $downloadable_watermark_files = [];
            $downloadable_watermark_counts = [];
            $downloadable_watermark_expiry = [];
            $transactionId = $this->dynamicink_generateRandomString(15);
            foreach( $items as $key => $item){
                $ebook_id           = get_post_meta($item['product_id'], '_custom_product_ebook_id', true);
                if(get_post_meta($item['product_id'], '_downloadable', true) == 'yes' && $ebook_id !='') {
                    $item_id[]        = $item['product_id'];
                    $item_download_count  = (get_post_meta($item['product_id'], '_download_limit', true) > 0 ? get_post_meta($item['product_id'], '_download_limit', true) * $item['quantity'] : '' );
                    $item_download_expiry  = (get_post_meta($item['product_id'], '_download_expiry', true) > 0 ? strtotime( $from_date . ' + ' . get_post_meta($item['product_id'], '_download_expiry', true) . ' DAY' ) : '');
                    $utoken = $this->dynamicink_generateRandomString(15);
                    
                    $data = array(
                        'email' => $email,
                        'transactionid' => $transactionId,
                        'utoken' => $utoken,
                        'first_name' => ((!empty($address['first_name']) && $address['first_name']) ? $address['first_name'] : $address['billing_first_name']),
                        'last_name' => ((!empty($address['last_name']) && $address['last_name']) ? $address['last_name'] : $address['billing_last_name']),
                        'uid'          => $ebook_id,
                        'order_status' => ($order->status == 'processing' ? 'paid' : 'unpaid'),
                        'order_id'     => $order_id,
                        'gdpr_customer_email' => $this->dynamicink_get_gdpr_customer_email($email),
                        'gdpr_customer_name' => $address['billing_first_name']." ".(!empty($address['billing_last_name']) ? substr($address['billing_last_name'], 0, 1) : ''),
                    );
                    $downloadable_watermark_files[$item['product_id']] = $ebook_id.'/'.$transactionId.'/'.$utoken;
                    $downloadable_watermark_counts[$item['product_id']] = $item_download_count;
                    $downloadable_watermark_expiry[$item['product_id']] = $item_download_expiry;
                    
                    // send API request via Wp_remote_post
                    /* set the complete URL, to process the order on the external system. which invokes the API */
                    $response = wp_remote_post( $this->ebook_api_url, array(
                                                                    'headers' => array("Content-type" => "application/json","x-api-key" => $this->ebook_api_key),
                                                                    'timeout'     => '50',
                                                                    'redirection' => '5',
                                                                    'httpversion' => '1.0',
                                                                    'sslverify' => false,
                                                                    'follow_redirects' => true,
                                                                    'body' => json_encode($data)
                                                                    ) );
                }
            }
            if(count($downloadable_watermark_files) > 0 && count($item_id) == count($downloadable_watermark_files)) {
                update_post_meta( $order_id, 'downloadable_watermark_files', json_encode($downloadable_watermark_files));
                update_post_meta( $order_id, 'downloadable_watermark_counts', json_encode($downloadable_watermark_counts));
                update_post_meta( $order_id, 'downloadable_watermark_expiry', json_encode($downloadable_watermark_expiry));
            }
        }
        $downloadable_watermark_files_final_altered = json_decode(get_post_meta($order_id, 'downloadable_watermark_files', true));
        if( count((array)$downloadable_watermark_files_final_altered) > 0 && ($order->has_status('completed') || (($order->has_status('completed') || $order->has_status('pending')) && $order->get_payment_method_title() == "PayPal" )) && $this->ebook_api_key !=''){
        $downloadable_show_watermark_counts = json_decode(get_post_meta($order_id, 'downloadable_watermark_counts', true));
        $downloadable_show_watermark_expiry = json_decode(get_post_meta($order_id, 'downloadable_watermark_expiry', true));
        
        $email_hash = function_exists( 'hash' ) ? hash( 'sha256', $order->get_billing_email() ) : sha1( $order->get_billing_email() );
        $order_key = $order->get_order_key();
        ?>
        <section class="woocommerce-order-downloads">
	<?php if ( isset( $show_title ) ) : ?>
		<h2 class="woocommerce-order-downloads__title"><?php esc_html_e( 'Downloads', 'woocommerce' ); ?></h2>
	<?php endif; ?>

	<table class="woocommerce-table woocommerce-table--order-downloads shop_table shop_table_responsive order_details">
		<thead>
			<tr>
				<?php foreach ( wc_get_account_downloads_columns() as $column_id => $column_name ) : ?>
				<th class="<?php echo esc_attr( $column_id ); ?>"><span class="nobr"><?php echo esc_html( $column_name ); ?></span></th>
				<?php endforeach; ?>
			</tr>
		</thead>

		<?php
                foreach ( $downloadable_watermark_files_final_altered as $productKey => $download ) : 
                        $productDetails  = wc_get_product( $productKey );
                        $download_url = $this->ebook_api_url.$download;
        ?>
			<tr>
				<?php foreach ( wc_get_account_downloads_columns() as $column_id => $column_name ) : ?>
					<td class="<?php echo esc_attr( $column_id ); ?>" data-title="<?php echo esc_attr( $column_name ); ?>">
						<?php
						if ( has_action( 'woocommerce_account_downloads_column_' . $column_id ) ) {
							do_action( 'woocommerce_account_downloads_column_' . $column_id, $productDetails );
						} else {
							switch ( $column_id ) {
								case 'download-product':
									if ( $productDetails->is_visible() ) {
										echo '<a href="' . esc_url( $productDetails->get_permalink() ) . '">' . esc_html( $productDetails->get_name() ) . '</a>';
									} else {
										echo esc_html( $productDetails->get_name() );
									}
									break;
								case 'download-file':
									echo '<a href="' . esc_url( $download_url ) . '" class="woocommerce-MyAccount-downloads-file button alt">Download</a>';
									break;
								case 'download-remaining':
									echo is_numeric( $downloadable_show_watermark_counts->$productKey ) ? esc_html( $downloadable_show_watermark_counts->$productKey ) : esc_html__( '&infin;', 'woocommerce' );
									break;
								case 'download-expires':
									if ( ! empty( $downloadable_show_watermark_expiry->$productKey ) ) {
										echo '<time datetime="' . esc_attr( date( 'Y-m-d', strtotime( $downloadable_show_watermark_expiry->$productKey ) ) ) . '" title="' . esc_attr( strtotime( $downloadable_show_watermark_expiry->$productKey ) ) . '">' . esc_html( date_i18n( get_option( 'date_format' ), strtotime( $downloadable_show_watermark_expiry->$productKey ) ) ) . '</time>';
									} else {
										esc_html_e( 'Never', 'woocommerce' );
									}
									break;
							}
						}
						?>
					</td>
				<?php endforeach; ?>
			</tr>
		<?php endforeach; ?>
	</table>
</section>
   <?php     return true;
        }
        return true;
    }
    
    public function dynamicink_product_custom_fields()
    {
        global $wp, $post;
        echo '<div class="product_custom_wp_field_ebook" style="display:none">';
        
        woocommerce_wp_text_input(
            array(
                'id' => '_custom_product_ebook_id',
                'placeholder' => "Leave Blank if you don't want to watermark",
                'label' => __('Watermark by DynamicInk', 'dynamicink'),
                'desc_tip' => 'true',
                'default' => get_post_meta(get_the_ID(), '_custom_product_ebook_id', true),
                'description' => 'Input ebook id here. You can find ebook id on www.dynamicink.co/ebooks'
            )
        );
        echo "</div></div><script>
            const checkbox_dw = document.getElementById('_downloadable');
            if(checkbox_dw.checked){
                document.querySelector('.product_custom_wp_field_ebook').style.cssText = 'display:block';
            }
            checkbox_dw.addEventListener('change', (event) => {
              if (event.currentTarget.checked) {
                document.querySelector('.product_custom_wp_field_ebook').style.cssText = 'display:block';
              } else {
                document.querySelector('.product_custom_wp_field_ebook').style.cssText = 'display:none';
              }
            });
            </script>";
    }
    
    public function dynamicink_product_custom_fields_save($post_id)
    {
        // Custom Product Watermark Downloads
        if( isset($_POST['_downloadable']) ){
            // Custom Product Ebook ID
            $woocommerce_custom_procut_ebook_id = trim(sanitize_text_field($_POST['_custom_product_ebook_id']));
            if (!empty($woocommerce_custom_procut_ebook_id))
                $woocommerce_custom_procut_ebook_id = sanitize_text_field($_POST['_custom_product_ebook_id']);
            else
                $woocommerce_custom_procut_ebook_id = '';
            update_post_meta($post_id, '_custom_product_ebook_id', esc_html($woocommerce_custom_procut_ebook_id));
        }else{
            update_post_meta($post_id, '_custom_product_ebook_id', '');
        }
        return true;
    }

	/**
	 * Loads all of our options for this plugin (stored as properties as well)
	 *
	 * @return array An array of options that can be passed to other classes
	 */
	public function dynamicink_init_options() {
		$options = array(
			'ebook_api_key'
		);

		$constructor = array();
		foreach ( $options as $option ) {
			$constructor[ $option ] = $this->$option = $this->get_option( $option );
		}

		return $constructor;
	}

	/**
	 * Tells WooCommerce which settings to display under the "integration" tab
	 */
	public function dynamicink_init_form_fields() {
		$this->form_fields = array(
			'ebook_api_key' => array(
				'title'       => __( 'Your API key', 'dynamicink' ),
				'type'        => 'text',
                'desc_tip'    => false,
				'placeholder' => 'Find your api key in www.dynamicink.co/account',
				'default'     => $this->get_option( 'ebook_api_key' )
			),
			'remove_my_ebook_api_service' => array(
				'label'       => __( 'Check this box and save to stop using DynamicInk', 'dynamicink' ),
				'type'        => 'checkbox',
                'desc_tip'    => false
			)
		);
        $this->dynamicink_apply_integration_template_css();
	}
    
    public function dynamicink_apply_integration_template_css(){
        if ( empty( $_GET['tab'] ) ) {
			return;
		}

		if ( 'integration' !== $_GET['tab'] ) {
			return;
		}
        if ( 'dynamicink' !== $_GET['section'] ) {
			return;
		}
        if($this->ebook_api_key != '') {
            echo '<style type="text/css">#woocommerce_dynamicink_ebook_api_key, label[for="woocommerce_dynamicink_ebook_api_key"]{display:none !important;}#woocommerce_dynamicink_remove_my_ebook_api_service, label[for="woocommerce_dynamicink_remove_my_ebook_api_service"]{display:block !important;}</style>';
        } else { 
            echo '<style type="text/css">#woocommerce_dynamicink_ebook_api_key, label[for="woocommerce_dynamicink_ebook_api_key"]{display:block !important;}#woocommerce_dynamicink_remove_my_ebook_api_service, label[for="woocommerce_dynamicink_remove_my_ebook_api_service"]{display:none !important;}</style>';
        }
        return true;
    }

	/**
	 * Santize our settings
	 * @see process_admin_options()
	 */
	public function dynamicink_sanitize_settings( $settings ) {
		// We're just going to make the api key all upper case characters since that's how our imaginary API works
        if(isset($settings['remove_my_ebook_api_service']) && $settings['ebook_api_key']==''){
            $settings['ebook_api_key'] = '';
            $settings['remove_my_ebook_api_service'] = 'no';
        }
		else{
			$settings['remove_my_ebook_api_service'] = 'no';
		}	
        $this->dynamicink_init_options();
        $this->dynamicink_apply_integration_template_css();
		return $settings;
	}

	/**
	 * Validate the API key
	 * @see validate_settings_fields()
	 */
	public function validate_ebook_api_key_field( $key ) {
		// get the posted value
		$value = sanitize_text_field($_POST[ $this->plugin_id . $this->id . '_' . $key ]);
        
        if(!empty($value)&& empty($this->ebook_api_key)){
            $response = wp_remote_post( $this->ebook_api_url, array(
                                                                    'headers' => array("Content-type" => "application/json","x-api-key" => $value),
                                                                    'timeout'     => '50',
                                                                    'httpversion' => '1.0',
                                                                    'sslverify' => false,
                                                                    'follow_redirects' => true,
                                                          ) );
              
            // Response body.
            $body = wp_remote_retrieve_body( $response );
            if(!empty($response) && !empty($body)) {
                if ( !empty( $value ) && $body != 'Found api-key') {
                    WC_Admin_Settings::add_error( esc_html__( $body, 'dynamicink' ) );
                }else{
                    return $value;
                }
            }
        }else{
            return '';
        }
	}
}
