<?php
/**
 * Email Downloads.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/email-downloads.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.4.0
 */

defined( 'ABSPATH' ) || exit;

$text_align = is_rtl() ? 'right' : 'left';

?><h2 class="woocommerce-order-downloads__title"><?php esc_html_e( 'Downloads', 'woocommerce' ); ?></h2>

<table class="td" cellspacing="0" cellpadding="6" style="width: 100%; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif; margin-bottom: 40px;" border="1">
	<thead>
		<tr>
			<?php foreach ( $columns as $column_id => $column_name ) : ?>
				<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php echo esc_html( $column_name ); ?></th>
			<?php endforeach; ?>
		</tr>
	</thead>

	<?php 
        $email_hash = function_exists( 'hash' ) ? hash( 'sha256', $order->get_billing_email() ) : sha1( $order->get_billing_email() );
        $order_key = $order->get_order_key();
    
        foreach ( $downloads as $productKey => $download ) : 
                $productDetails  = wc_get_product( $productKey );
                $download_url = $ebook_api_url.$download;
    ?>
		<tr>
			<?php foreach ( $columns as $column_id => $column_name ) : ?>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>;">
					<?php
					if ( has_action( 'woocommerce_email_downloads_column_' . $column_id ) ) {
						do_action( 'woocommerce_email_downloads_column_' . $column_id, $download, $plain_text );
					} else {
						switch ( $column_id ) {
                            case 'download-product':
                                if ( $productDetails->is_visible() ) {
                                    echo '<a href="' . esc_url( $productDetails->get_permalink() ) . '">' . esc_html( $productDetails->get_name() ) . '</a>';
                                } else {
                                    echo esc_html( $productDetails->get_name() );
                                }
                                break;
                            case 'download-file':
                                echo '<a href="' . esc_url( $download_url ) . '" class="woocommerce-MyAccount-downloads-file button alt">Download</a>';
                                break;
                            case 'download-remaining':
                                echo is_numeric( $downloadable_show_watermark_counts->$productKey ) ? esc_html( $downloadable_show_watermark_counts->$productKey ) : esc_html__( '&infin;', 'woocommerce' );
                                break;
                            case 'download-expires':
                                if ( ! empty( $downloadable_show_watermark_expiry->$productKey ) ) {
                                    echo '<time datetime="' . esc_attr( date( 'Y-m-d', strtotime( $downloadable_show_watermark_expiry->$productKey ) ) ) . '" title="' . esc_attr( strtotime( $downloadable_show_watermark_expiry->$productKey ) ) . '">' . esc_html( date_i18n( get_option( 'date_format' ), strtotime( $downloadable_show_watermark_expiry->$productKey ) ) ) . '</time>';
                                } else {
                                    esc_html_e( 'Never', 'woocommerce' );
                                }
                                break;
						}
					}
					?>
				</td>
			<?php endforeach; ?>
		</tr>
	<?php endforeach; ?>
</table>
